import java.io.BufferedReader;
import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.HashSet;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class LogDiff {
   private Matcher ipMatch =
      Pattern.compile("\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}\\.\\d{1,3}").matcher("");
   
   private File log1;
   private File log2;
   
   private HashSet<String> log1Ips = new HashSet<String>();
   private HashSet<String> log2Ips = new HashSet<String>();
   
   public LogDiff(String log1, String log2) {
      this.log1 = new File(log1);
      this.log2 = new File(log2);
   }
   
   private void parseIps(BufferedReader reader, HashSet<String> set) throws IOException {
      String line;
      int matchStart;
      
      while ((line=reader.readLine()) != null) {
         ipMatch.reset(line);
         matchStart = 0;
         
         while (ipMatch.find(matchStart)) {
            set.add(line.substring(ipMatch.start(), ipMatch.end()));
            matchStart = ipMatch.end();
         }
      }
   }
   
   public void parse() throws IOException {
      BufferedReader reader1 = null, reader2 = null;
      try {
         reader1 = new BufferedReader(new FileReader(log1));
         parseIps(reader1, log1Ips);
         
         reader2 = new BufferedReader(new FileReader(log2));
         parseIps(reader2, log2Ips);
      } finally {
         if (reader1 != null) reader1.close();
         if (reader2 != null) reader2.close();
      }
   }
   
   public void printDiff() {
      HashSet<String> diff1 = (HashSet<String>)log1Ips.clone();
      diff1.removeAll(log2Ips);
      
      HashSet<String> diff2 = (HashSet<String>)log2Ips.clone();
      diff2.removeAll(log1Ips);
      
      System.out.printf("Only in %s %s\n", log1, diff1);
      System.out.printf("Only in %s %s\n", log2, diff2);
   }
   
   public static void main(String[] args) throws IOException {
      LogDiff ld = new LogDiff(args[0], args[1]);
      ld.parse();
      ld.printDiff();
   }
}

